pub struct TimeStampFlags {
	last_seen: Vec<u16>,
	current_timestamp: u16,
}

impl TimeStampFlags {
	pub fn new(id_count: usize) -> TimeStampFlags {
		TimeStampFlags {
			last_seen: vec![0; id_count],
			current_timestamp: 1,
		}
	}

	pub fn is_set(&self, id: usize) -> bool {
		unsafe { *self.last_seen.get_unchecked(id) == self.current_timestamp }
	}

	pub fn set(&mut self, id: usize) {
		unsafe {
			*self.last_seen.get_unchecked_mut(id) = self.current_timestamp;
		}
	}

	// pub fn reset_one(&mut self, id: usize) {
	// 	unsafe {
	// 		*self.last_seen.get_unchecked_mut(id) = self.current_timestamp + 1;
	// 	}
	// }

	pub fn reset_all(&mut self) {
		self.current_timestamp = self.current_timestamp.wrapping_add(1); // '+' in Rust corresponds to panicking add and gives an error
		if self.current_timestamp == 0 {
			// self.last_seen.fill(0); 			// Unstable as of Rust 1.45
			for i in self.last_seen.iter_mut() {
				*i = 0;
			}
			self.current_timestamp = 1;
		}
	}
}
