use crate::data_structures::graphs::edge::WeightedEdge;
use crate::data_structures::graphs::graph::{Graph, GraphTrait};
use crate::data_structures::graphs::weight::UnitWeight;

use std::error::Error;

use osmpbfreader::OsmPbfReader;

pub fn build_from_file(filename: String) -> Result<Graph<WeightedEdge<UnitWeight<usize>>>, Box<dyn Error>> {
	println!("In the build function.");

	let reader = std::fs::File::open(&std::path::Path::new(&filename))?;
	let mut pbf = OsmPbfReader::new(reader);

	let mut nb_nodes = 0;
	let mut nb_ways = 0;
	let mut nb_way_nodes = 0;
	let mut nb_rels = 0;
	let mut nb_rel_refs = 0;

	println!("Starting to read records.. ");
	for obj in pbf.par_iter().map(Result::unwrap) {
		match obj {
			osmpbfreader::OsmObj::Node(_node) => {
				nb_nodes += 1;
			}
			osmpbfreader::OsmObj::Way(way) => {
				nb_ways += 1;
				nb_way_nodes += way.nodes.len();
			}
			osmpbfreader::OsmObj::Relation(rel) => {
				nb_rels += 1;
				nb_rel_refs += rel.refs.len();
			}
		}
	}
	println!("{} nodes", nb_nodes);
	println!(
		"{} ways, mean |nodes|: {}",
		nb_ways,
		nb_way_nodes as f64 / nb_ways as f64
	);
	println!(
		"{} relations, mean |references|: {}",
		nb_rels,
		nb_rel_refs as f64 / nb_rels as f64
	);
	println!("Done reading records...");

	let _graph = Graph::<WeightedEdge<UnitWeight<usize>>>::new(nb_nodes);
	unimplemented!()
}
